@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Copyright (C) 2012, Wolfgang Scherer, <Wolfgang.Scherer at gmx.de>
-# Sponsored by WIEDENMANN SEILE GMBH, http://www.wiedenmannseile.de
 #
-# This file is part of Wiedenmann Utilities.
+# This file is part of AdHoc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,13 +33,17 @@ Options
   -q, --quiet           suppress warnings
   -v, --verbose         verbose test output
   -d, --debug=NUM       show debug information
+  -h, --help            display this help message
 
-  -t, --test            run doc tests
-  --implode             implode script with adhoc
+  --template list       show available templates.
+  --template=NAME       extract named template to standard
+                        output. Default NAME is `-`.
+  --extract=DIR         extract adhoc files to directory DIR (default: `.`)
   --explode=DIR         explode script with adhoc in directory DIR
                         (default `__adhoc__`)
-  --extract=DIR         extract adhoc files to directory DIR (default: `.`)
-  -h, --help            display this help message
+  --implode             implode script with adhoc
+
+  -t, --test            run doc tests
 
 Description
 ===========
@@ -1317,8 +1320,15 @@ def main(argv):                                            # ||:fnc:||
                 if path_dir not in sys.path:
                     sys.path.append(path_dir)
             if not have_adhoc:
-                import adhoc
-                AdHoc = adhoc.AdHoc
+                try:
+                    import adhoc
+                    AdHoc = adhoc.AdHoc
+                except ImportError:
+                    adhoc_compile = False
+                    try:
+                        from rt_adhoc import RtAdHoc as Adhoc
+                    except ImportError:
+                        pass
         else:
             adhoc_compile = False
             AdHoc = RtAdHoc
@@ -1342,7 +1352,7 @@ def main(argv):                                            # ||:fnc:||
             #         ["warning: ", os.path.basename(file_),
             #          " already imploded!\n"])
             # @:adhoc_enable:@
-            sys.stdout.write(source)
+            AdHoc.write_source('-', source)
         # explode
         elif _parameters.explode:
             AdHoc.export_dir = _parameters.adhoc_arg
@@ -1362,7 +1372,7 @@ def main(argv):                                            # ||:fnc:||
             else:
                 template = AdHoc.get_named_template(
                     template_name, file_, source)
-                sys.stdout.write(template)
+                AdHoc.write_source('-', template)
 
         # restore for subsequent calls to main
         if not have_adhoc:
